@@ -148,7 +148,7 @@ class Data:
     sr_mail_crypt = {'mode':"w",'value':'tls'}
     # порт получения
     sr_mail_port = {'mode':"w",'value':'143'}
-    # тип получения - pop/imap
+    # тип получения - pop3/imap/all
     sr_mail_type = {'mode':"w",'value':'imap'}
     # шифрование отправки - ''/ssl/tls
     sr_mail_send_crypt = {'mode':"w"}
@@ -222,19 +222,19 @@ class Data:
     #-----------------------------------------------------
     #Сервис Unix
     #-----------------------------------------------------
-    #DN админстратора сервиса Unix (он, же DN сервиса)
+    #DN администратора сервиса Unix (он, же DN сервиса)
     #V soft_ldap_admin_unix
     ld_unix_dn = {}
 
-    #имя админстратора сервиса Unix
+    #имя администратора сервиса Unix
     #V soft_ldap_admin_unix_name
     ld_unix_login = {'value':'Unix'}
 
-    #пароль админстратора сервиса Unix
+    #пароль администратора сервиса Unix
     #V soft_ldap_admin_unixpw
     ld_unix_pw = {}
 
-    #hash пароля админстратора сервиса Unix
+    #hash пароля администратора сервиса Unix
     #V soft_ldap_admin_unixpw_hash
     ld_unix_hash = {}
 
@@ -246,31 +246,31 @@ class Data:
     #-----------------------------------------------------
     #Сервис Samba
     #-----------------------------------------------------
-    #DN админстратора сервиса Samba (он, же DN сервиса)
+    #DN администратора сервиса Samba (он, же DN сервиса)
     #V soft_ldap_admin_samba
     ld_samba_dn = {}
 
-    #имя админстратора сервиса Samba
+    #имя администратора сервиса Samba
     #V soft_ldap_admin_samba_name
     ld_samba_login = {'value':'Samba'}
 
-    #пароль админстратора сервиса Samba
+    #пароль администратора сервиса Samba
     #V soft_ldap_admin_sambapw
     ld_samba_pw = {}
 
-    #hash пароля админстратора сервиса Samba
+    #hash пароля администратора сервиса Samba
     #V soft_ldap_admin_sambapw_hash
     ld_samba_hash = {}
 
     # Директория настроек пользователя windows
     #V soft_samba_winprofile_path
     sr_samba_winprof_path = {\
-                    'value':'/var/calculate/server-data/samba/win/profiles'}
+                    'value':'/var/calculate/server-data/samba/profiles/win'}
 
     # Директория хранения настроек пользователя linux
     #V soft_samba_linprofile_path
     sr_samba_linprof_path = {\
-                    'value':'/var/calculate/server-data/samba/unix/profiles'}
+                    'value':'/var/calculate/server-data/samba/profiles/unix'}
 
     # Домашняя директория
     #V soft_samba_home_path
@@ -280,7 +280,7 @@ class Data:
     # Директория netlogon
     #V soft_samba_winlogon_path
     sr_samba_winlogon_path = {\
-                    'value':'/var/calculate/server-data/samba/win/netlogon'}
+                    'value':'/var/calculate/server-data/samba/netlogon'}
 
     # Директория share
     #V soft_samba_share_path
@@ -295,19 +295,19 @@ class Data:
     #-----------------------------------------------------
     #Сервис Mail
     #-----------------------------------------------------
-    #DN админстратора сервиса Mail (он, же DN сервиса)
+    #DN администратора сервиса Mail (он, же DN сервиса)
     #V soft_ldap_admin_mail
     ld_mail_dn = {}
 
-    #имя админстратора сервиса Mail
+    #имя администратора сервиса Mail
     #V soft_ldap_admin_mail_name
     ld_mail_login = {'value':'Mail'}
 
-    #пароль админстратора сервиса Mail
+    #пароль администратора сервиса Mail
     #V soft_ldap_admin_mailpw
     ld_mail_pw = {}
 
-    #hash пароля админстратора сервиса Mail
+    #hash пароля администратора сервиса Mail
     #V soft_ldap_admin_mailpw_hash
     ld_mail_hash = {}
 
@@ -319,7 +319,7 @@ class Data:
 
     # Директория хранения писем
     #V soft_ldap_mail_path
-    sr_mail_path = {'value':'/var/calculate/server-data/mail/imap'}
+    sr_mail_path = {'value':'/var/calculate/server-data/mail'}
 
     #Настроен или нет сервис Mail
     #V soft_mail_setup
@@ -329,19 +329,19 @@ class Data:
     #-----------------------------------------------------
     #Сервис Jabber
     #-----------------------------------------------------
-    #DN админстратора сервиса Jabber (он, же DN сервиса)
+    #DN администратора сервиса Jabber (он, же DN сервиса)
     #V soft_ldap_admin_jabber
     ld_jabber_dn = {}
 
-    #имя админстратора сервиса Jabber
+    #имя администратора сервиса Jabber
     #V soft_ldap_admin_jabber_name
     ld_jabber_login = {'value':'Jabber'}
 
-    #пароль админстратора сервиса Jabber
+    #пароль администратора сервиса Jabber
     #V soft_ldap_admin_jabberpw
     ld_jabber_pw = {}
 
-    #hash пароля админстратора сервиса Jabber
+    #hash пароля администратора сервиса Jabber
     #V soft_ldap_admin_jabberpw_hash
     ld_jabber_hash = {}
 
@@ -356,19 +356,19 @@ class Data:
     # имя компьютера с настроенным сервисом FTP
     cl_remote_ftp = {}
 
-    #DN админстратора сервиса FTP (он, же DN сервиса)
+    #DN администратора сервиса FTP (он, же DN сервиса)
     #V soft_ldap_admin_ftp
     ld_ftp_dn = {}
 
-    #имя админстратора сервиса FTP
+    #имя администратора сервиса FTP
     #V soft_ldap_admin_ftp_name
     ld_ftp_login = {'value':'Ftp'}
 
-    #пароль админстратора сервиса FTP
+    #пароль администратора сервиса FTP
     #V soft_ldap_admin_ftppw
     ld_ftp_pw = {}
 
-    #hash пароля админстратора сервиса FTP
+    #hash пароля администратора сервиса FTP
     #V soft_ldap_admin_ftppw_hash
     ld_ftp_hash = {}
 
@@ -392,10 +392,29 @@ class Data:
     # Calculate плюс версия калкулэйта для записи в заголовок файла
     # объединяемого с профилем
     #setup_name
-    cl_ver = {'value':'Calculate-server 2.0.5'}
-    #-----------------------------------------------------
-    #Служебные переменные
-    #-----------------------------------------------------
-    #запущенные сервисы CDS
-    #? soft_service_allive
-    #sr_run =   {}
+    cl_ver = {'value':'Calculate-server 2.0.6'}
+
+    #DN LDAP ветки, в котором будут находится служебные ветки
+    ld_ldap_dn = {}
+    #имя LDAP ветки 
+    ld_ldap_login = {'value':'LDAP'}
+
+    #Репликация
+    # имя компьютера c включенной репликацией
+    ld_repl_host = {}
+    #Включена или нет репликация
+    ld_repl_set  = {'mode':"w",'value':'off'}
+    # DN ветки репликации
+    ld_repl_dn = {}
+    # имя ветки репликации
+    ld_repl_login = {'value':'Replication'}
+    # пароль ветки репликации
+    ld_repl_pw = {}
+    # хеш пароля ветки репликации
+    ld_repl_hash = {}
+    #DN ветки хранения последнего посещенного сервера
+    ld_repl_worked_dn = {}
+    #имя ветки 
+    ld_repl_worked_login = {'value':'Worked'}
+    #DN ветки хранения аттрибутов доступа пользователя
+    ld_repl_access_dn = {}
